""" Copy + Paste in Windows
"""

# found @ http://code.activestate.com/recipes/150115/

from .base import * 

try:
    import win32clipboard as clip
    import win32con
except ImportError as why:
    raise Pywin32NotFound


def copy(string, **kwargs):
    """Copy given string into system clipboard."""

    clip.OpenClipboard()
    clip.EmptyClipboard()
    clip.SetClipboardData(win32con.CF_UNICODETEXT, string) 
    clip.CloseClipboard()

    return

def paste(**kwargs):
    """Returns system clipboard contents."""

    clip.OpenClipboard() 
    d = clip.GetClipboardData(win32con.CF_UNICODETEXT)
    clip.CloseClipboard() 
    return d 

 



""" Copy + Paste in Windows
"""

# found @ http://code.activestate.com/recipes/150115/

from .base import *

try:
    import clr
    clr.AddReference('PresentationCore')
    import System.Windows.Clipboard as clip
except ImportError as why:
    raise ClrNotFound


def copy(string, **kwargs):
    """Copy given string into system clipboard."""

    clip.SetText(string)
    return


def paste(**kwargs):
    """Returns system clipboard contents."""

    if clip.ContainsText():
        return clip.GetText()

    return None





# -*- coding: utf-8 -*-

class ToolNotFound(Exception):
    """A needed tool was not found."""
    
class Pywin32NotFound(ToolNotFound):
    """PyWin32 must be installed."""

class ClrNotFound(ToolNotFound):
    """clr must be installed."""

class XcodeNotFound(ToolNotFound):
    """xcode must be installed."""

class XclipNotFound(ToolNotFound):
    """xclip must be installed.
       On Ubuntu,
       $ apt-get install xclip
    """
class TkinterNotFound(ToolNotFound):
    """Tkinter must be installed"""




"""
Copy + Paste in Windows, Linux or Mac

found @ http://code.activestate.com/recipes/150115/
"""

from .base import *

try:
    from Tkinter import Tk
except ImportError as why:
    raise TkinterNotFound

def copy(string, **kwargs):
    """Copy given string into system clipboard."""
    window = Tk()
    window.withdraw()
    window.clipboard_clear()
    window.clipboard_append(string)
    window.destroy()
    return

def paste(**kwargs):
    """Returns system clipboard contents."""
    window = Tk()
    window.withdraw()
    d = window.selection_get(selection = 'CLIPBOARD')
    return d
